@@ -151,115 +151,6 @@ class TestJobsUnified701(TestClass):
         )
         return self.__job_class_tester.test_skills(stats, skills_and_expected_damage)
 
-    @TestClass.is_a_test
-    def test_pld_skills(self):
-        stats = Stats(
-            wd=126,
-            weapon_delay=2.24,
-            main_stat=2891,
-            det_stat=1844,
-            crit_stat=2377,
-            dh_stat=1012,
-            speed_stat=400,
-            tenacity=751,
-            job_class="PLD",
-            version=self.__version,
-            level=self.__level,
-        )
-        skills_and_expected_damage = (
-            ("Auto", SkillModifier(), 1699),
-            ("Fast Blade", SkillModifier(), 5618),
-            ("Riot Blade", SkillModifier(force_combo=True), 8406),
-            ("Riot Blade", SkillModifier(), 4332),
-            ("Total Eclipse", SkillModifier(), 2547),
-            ("Shield Bash", SkillModifier(), 2547),
-            ("Shield Lob", SkillModifier(), 2547),
-            ("Prominence", SkillModifier(force_combo=True), 4331),
-            ("Prominence", SkillModifier(), 2547),
-            ("Circle of Scorn", SkillModifier(), 7372),
-            ("Goring Blade", SkillModifier(), 17849),
-            ("Royal Authority", SkillModifier(force_combo=True), 11197),
-            ("Royal Authority", SkillModifier(), 4588),
-            ("Holy Spirit", SkillModifier(), 9443),
-            ("Holy Spirit", SkillModifier(with_condition="Divine Might"), 11982),
-            ("Holy Spirit", SkillModifier(with_condition="Requiescat"), 17103),
-            (
-                "Holy Spirit",
-                SkillModifier(with_condition="Divine Might, Requiescat"),
-                11983,
-            ),
-            ("Requiescat", SkillModifier(), 8167),
-            ("Holy Circle", SkillModifier(), 2548),
-            ("Holy Circle", SkillModifier(with_condition="Divine Might"), 5100),
-            ("Holy Circle", SkillModifier(with_condition="Requiescat"), 7651),
-            (
-                "Holy Circle",
-                SkillModifier(with_condition="Divine Might, Requiescat"),
-                5099,
-            ),
-            ("Intervene", SkillModifier(), 3824),
-            ("Atonement", SkillModifier(), 11220),
-            ("Sepulchre", SkillModifier(), 12251),
-            ("Supplication", SkillModifier(), 11732),
-            ("Confiteor", SkillModifier(), 11223),
-            ("Confiteor", SkillModifier(with_condition="Requiescat"), 23984),
-            ("Expiacion", SkillModifier(), 11470),
-            ("Blade of Faith", SkillModifier(), 6112),
-            ("Blade of Faith", SkillModifier(with_condition="Requiescat"), 18868),
-            ("Blade of Truth", SkillModifier(), 8667),
-            ("Blade of Truth", SkillModifier(with_condition="Requiescat"), 21448),
-            ("Blade of Valor", SkillModifier(), 11216),
-            ("Blade of Valor", SkillModifier(with_condition="Requiescat"), 23957),
-            ("Blade of Honor", SkillModifier(), 25532),
-            ("Imperator", SkillModifier(), 14798),
-        )
-
-        return self.__job_class_tester.test_skills(stats, skills_and_expected_damage)
-
-    @TestClass.is_a_test
-    def test_pld_req_stacks(self):
-        stats = Stats(
-            wd=126,
-            weapon_delay=2.24,
-            main_stat=2891,
-            det_stat=1844,
-            crit_stat=2377,
-            dh_stat=1012,
-            speed_stat=400,
-            tenacity=751,
-            job_class="PLD",
-            version=self.__version,
-            level=self.__level,
-        )
-
-        rb = RotationBuilder(
-            stats, self.__skill_library, enable_autos=False, ignore_trailing_dots=True
-        )
-        rb.add_next("Requiescat")
-        rb.add_next("Confiteor")
-        rb.add_next("Confiteor")
-        rb.add_next("Imperator")
-        rb.add_next("Confiteor")
-        rb.add_next("Confiteor")
-        rb.add_next("Confiteor")
-        rb.add_next("Confiteor")
-        # last one should be weaker, since we should only have 4 charges from early imperator
-        rb.add_next("Confiteor")
-
-        expected = (
-            ("Requiescat", 8157),
-            ("Confiteor", 23990),
-            ("Confiteor", 23990),
-            ("Imperator", 14802),
-            ("Confiteor", 23990),
-            ("Confiteor", 23990),
-            ("Confiteor", 23990),
-            ("Confiteor", 23990),
-            ("Confiteor", 11212),
-        )
-
-        return self.__job_class_tester.test_rotation_damage(rb, expected)
-
     @TestClass.is_a_test
     def test_whm_skills(self):
         stats = Stats(
@@ -1694,7 +1585,7 @@ class TestJobsUnified701(TestClass):
         rb.add_next("Umbral Flare")
         rb.add_next("Enkindle Solar Bahamut")
 
-        expected_damage = 698949
+        expected_damage = 690759
         expected_total_time = 47580
         return self.__job_class_tester.test_aggregate_rotation(
             rb, expected_damage, expected_total_time
